*****************
Statespace Models
*****************

.. automodule:: pymc_extras.statespace.models
.. autosummary::
   :toctree: generated

    BayesianSARIMA
    BayesianVARMAX

*********************
Structural Components
*********************

.. currentmodule:: pymc_extras.statespace.models
.. toctree::
   :maxdepth: 2

   models/structural
